@@ -10,11 +10,10 @@ BASE_GIT_COMMIT=$(git rev-parse --verify HEAD)
 [ -z "${BASE_GIT_COMMIT}" ] && echo "No git commit hash found" && exit 1
 
 BASE_CREATION_TIME=$(date -u +"%Y-%m-%dT%H:%M:%SZ")
-# Docker tags don't like colons so use shorter version of ISO 8601 for them.
-BASE_CREATION_TIME_SHORT=$(date -d "$BASE_CREATION_TIME" -u +"%Y%m%dT%H%M%SZ")
+
+: "${MONASCA_COMMON_TAG:="master"}"
 
 docker build --no-cache \
     --build-arg BASE_CREATION_TIME="$BASE_CREATION_TIME" \
     --build-arg BASE_GIT_COMMIT="$BASE_GIT_COMMIT" \
-    --tag monasca/base:master \
-    --tag monasca/base:"$BASE_CREATION_TIME_SHORT" .
+    --tag monasca/base:"$MONASCA_COMMON_TAG" .
